#TITLE: van De Rijn LMS

#OWNER: Christopher Eeles, christopher.eeles@uhnresearch.ca
#DATE: 2020/06/11

#DESC: This project will use patient sample, cancer cell-line and PDX data to 
    identify molecular subtypes in Leiomyosarcoma. The subtypes will be correlated
    with clinical outcomes and drug response data to formulate subtype specific
    treatment optimizations as well as identify potential chemotherapy drugs.
    Assuming useful subtypes are identified, the molecular data will be used 
    to build a classifier which can be applied to new patient tumour samples.

#DIR: TCGA_samples - Data and subtyping analysis of high quality LMS samples from TCGA
    van_de_Rijn_samples - Data and subtyping analysis of FFPE


Testing
For further details see the DOC files in each subdirectory.


